<?php
declare(strict_types=1);

namespace Drupal\membership_entity\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the 'member_id' widget.
 *
 * @FieldWidget(
 *   id = "member_id",
 *   label = @Translation("Member ID"),
 *   description = @Translation("An autogenerated Member ID"),
 *   field_types = {
 *    "member_id"
 *   }
 * )
 */
class MemberIdWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $manager = \Drupal::service('plugin.manager.member_id');
    $plugin_id = $this->fieldDefinition->getSetting('member_id_plugin');
    $plugin = $manager->createInstance($plugin_id, []);

    $element['test'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Test'),
    ];

    return $element; // + $plugin->optionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    return parent::settingsSummary(); // TODO: Change the autogenerated stub
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->value) ? $items[$delta]->value : NULL,
      '#size' => 15,
      '#maxlength' => 50,
    ];
  }

}
